@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Term::ANSIColor qw//;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 our @EXPORT = map { ($_.'f', $_.'ff') } qw/crit warn info debug croak/;
 push @EXPORT, 'ddf';
 
@@ -180,7 +180,7 @@ sub _log {
             push @stack, "$caller[1] line $caller[2]";
             $i++;
         }
-        $trace = join " ,", @stack
+        $trace = join ", ", @stack
     }
     else {
         my @caller = caller($TRACE_LEVEL+1);
@@ -477,7 +477,7 @@ If NONE is set, no output except croakf and croakff. Default log level is DEBUG.
 
 Serialize message with Data::Dumper.
 
-  warnf("%s",{ foo => bar}); # HASH(0x100804ed0)
+  warnf("%s", {foo => 'bar'}); # HASH(0x100804ed0)
 
   local $Log::Minimal::AUTODUMP = 1;
   warnf("dump is %s", {foo=>'bar'}); #dump is {foo=>'bar'}
